@@ -1,20 +1,21 @@
 import os
+import pathlib
 import tempfile
+import functools
 import contextlib
 import types
 import importlib
-from pathlib import Path
-from functools import singledispatch
 
-from ._compat import package_spec
+from typing import Union, Any, Optional
+from .abc import ResourceReader, Traversable
 
-if False:  # TYPE_CHECKING
-    from typing import Union, Any, Optional
-    from .abc import ResourceReader
-    Package = Union[types.ModuleType, str]
+from ._compat import wrap_spec
+
+Package = Union[types.ModuleType, str]
 
 
 def files(package):
+    # type: (Package) -> Traversable
     """
     Get a Traversable resource from a package
     """
@@ -30,7 +31,7 @@ def normalize_path(path):
     str_path = str(path)
     parent, file_name = os.path.split(str_path)
     if parent:
-        raise ValueError('{!r} must be only a file name'.format(path))
+        raise ValueError(f'{path!r} must be only a file name')
     return file_name
 
 
@@ -45,18 +46,15 @@ def get_resource_reader(package):
     # zipimport.zipimporter does not support weak references, resulting in a
     # TypeError.  That seems terrible.
     spec = package.__spec__
-    reader = getattr(spec.loader, 'get_resource_reader', None)
+    reader = getattr(spec.loader, 'get_resource_reader', None)  # type: ignore
     if reader is None:
         return None
-    return reader(spec.name)
+    return reader(spec.name)  # type: ignore
 
 
 def resolve(cand):
     # type: (Package) -> types.ModuleType
-    return (
-        cand if isinstance(cand, types.ModuleType)
-        else importlib.import_module(cand)
-        )
+    return cand if isinstance(cand, types.ModuleType) else importlib.import_module(cand)
 
 
 def get_package(package):
@@ -66,8 +64,8 @@ def get_package(package):
     Raise an exception if the resolved module is not a package.
     """
     resolved = resolve(package)
-    if package_spec(resolved).submodule_search_locations is None:
-        raise TypeError('{!r} is not a package'.format(package))
+    if wrap_spec(resolved).submodule_search_locations is None:
+        raise TypeError(f'{package!r} is not a package')
     return resolved
 
 
@@ -76,7 +74,7 @@ def from_package(package):
     Return a Traversable object for the given package.
 
     """
-    spec = package_spec(package)
+    spec = wrap_spec(package)
     reader = spec.loader.get_resource_reader(spec.name)
     return reader.files()
 
@@ -91,7 +89,7 @@ def _tempfile(reader, suffix=''):
         os.write(fd, reader())
         os.close(fd)
         del reader
-        yield Path(raw_path)
+        yield pathlib.Path(raw_path)
     finally:
         try:
             os.remove(raw_path)
@@ -99,7 +97,7 @@ def _tempfile(reader, suffix=''):
             pass
 
 
-@singledispatch
+@functools.singledispatch
 def as_file(path):
     """
     Given a Traversable object, return that object as a
@@ -108,7 +106,7 @@ def as_file(path):
     return _tempfile(path.read_bytes, suffix=path.name)
 
 
-@as_file.register(Path)
+@as_file.register(pathlib.Path)
 @contextlib.contextmanager
 def _(path):
     """
